/*
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Luis de-la-Fuente-Valentín, Universidad Internacional de La Rioja, UNIR, www.unir.net
 * Version: 1
 * Date: 2014-09-29
 * Copyright: Copyright (C) Universidad Internacional de La Rioja, UNIR
 * License: This software is provided as freeware. 

 Freeware products are provided free of charge. Freeware software may be used as many 
 times as you like, for as long as you like. You may copy and distribute copies of 
 this program provided that you keep this copyright notice and disclaimer of warranty
 intact, and recipients must be bound by the terms therein. You must not charge money
 or fees for the software product to anyone except to cover distribution costs. You 
 must acknowledge and cite the authorship of this software by UNIR. The copyright 
 holder reserves the right to reclassify this software as a non-freeware product at 
 any time (i.e. shareware, licensed royalty software, or public domain). Doing so will
 not modify the license agreement of previously distributed executables.
 */
package org.intuitel.slom;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

/**
*
* Java representation of INTUITEL Knowledge Object.
*
* <p>The SLOM course description establishes that the course content is organized 
* as Concept Containers at a higher level, and Knowledge Objects at a lower level 
* of abstraction. That is, the Concept Container contains several Knowledge Objects, 
* which contain the actual course material.<p>
*
* <p>Knowledge Objects refers to a particular Concept Container, and are sequence by
* means of Micro Learning Pathways. Knowledge Object contain metadata description given
* by a list of properties.</p>
*
* <p>This class provides a Java representation of the <b>Knowledge Object</b>.</p>
*
* <p>Further information of the SLOM format can be found at the 
* <a href="http:www.intuitel.de/resources">INTUITEL project page</a>, at deliverable D4.1</p>
* 
* @author  Luis de-la-Fuente-Valentín
* @since   1.0
*/
public class KnowledgeObject {

    private String id;
    /*private String title;
    private String description;
    private String knolwdgeType;
    private String mediaType;
    private String preferredLocation;
    private String difficultyLevel;
    private String eqfLevel;
    private String learningTime;
    private String language;
    private int minimalHeight;
    private int minimalWidth;
    private int recommendedAge;
    private int recommendedHeight;
    private int recommendedWidth;
    private int size;
    private String subtitles;
    private String suitableForBlind;
    private String suitableForMute;*/
    private Map<String,String> properties;
    private ArrayList<MicroLP> microLPs;//MicroLPs where this knowledge object is present

    /**
    *
    * Creates an empty KnowledgeObject.
    *
    * <p>Creates a KnowledgeObject object, with the id given as parameter and with empty lists 
    * of properties and MicroLPs</p>
    *
    * <p>Therefore, ConceptContainer configuration is required to complete the object setup</p>
    *
    * @param id The id of the ConceptContainer
    */    
    public KnowledgeObject(String id) {
        setId(id);
        properties = new HashMap();
        microLPs = new ArrayList();
    }

    /**
    * Gets the title of this KnowledgeObject.
    * 
    * @return The title of this KnowledgeObject.
    */      
    public String getId() {
        return id;
    }
    
    /**
    * Sets the id of this KnowledgeObject.
    * 
    * @param id The id to set.
    */
    public void setId(String id) {
        this.id = id;
    }
/*
    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getKnolwdgeType() {
        return knolwdgeType;
    }

    public void setKnolwdgeType(String knolwdgeType) {
        this.knolwdgeType = knolwdgeType;
    }

    public String getMediaType() {
        return mediaType;
    }

    public void setMediaType(String mediaType) {
        this.mediaType = mediaType;
    }

    public String getPreferredLocation() {
        return preferredLocation;
    }

    public void setPreferredLocation(String preferredLocation) {
        this.preferredLocation = preferredLocation;
    }

    public String getDifficultyLevel() {
        return difficultyLevel;
    }

    public void setDifficultyLevel(String difficultyLevel) {
        this.difficultyLevel = difficultyLevel;
    }

    public String getEqfLevel() {
        return eqfLevel;
    }

    public void setEqfLevel(String eqfLevel) {
        this.eqfLevel = eqfLevel;
    }

    public String getLearningTime() {
        return learningTime;
    }

    public void setLearningTime(String learningTime) {
        this.learningTime = learningTime;
    }

    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }

    public int getMinimalHeight() {
        return minimalHeight;
    }

    public void setMinimalHeight(int minimalHeight) {
        this.minimalHeight = minimalHeight;
    }

    public int getMinimalWidth() {
        return minimalWidth;
    }

    public void setMinimalWidth(int minimalWidth) {
        this.minimalWidth = minimalWidth;
    }

    public int getRecommendedAge() {
        return recommendedAge;
    }

    public void setRecommendedAge(int recommendedAge) {
        this.recommendedAge = recommendedAge;
    }

    public int getRecommendedHeight() {
        return recommendedHeight;
    }

    public void setRecommendedHeight(int recommendedHeight) {
        this.recommendedHeight = recommendedHeight;
    }

    public int getRecommendedWidth() {
        return recommendedWidth;
    }

    public void setRecommendedWidth(int recommendedWidth) {
        this.recommendedWidth = recommendedWidth;
    }

    public int getSize() {
        return size;
    }

    public void setSize(int size) {
        this.size = size;
    }

    public String getSubtitles() {
        return subtitles;
    }

    public void setSubtitles(String subtitles) {
        this.subtitles = subtitles;
    }

    public String getSuitableForBlind() {
        return suitableForBlind;
    }

    public void setSuitableForBlind(String suitableForBlind) {
        this.suitableForBlind = suitableForBlind;
    }

    public String getSuitableForMute() {
        return suitableForMute;
    }

    public void setSuitableForMute(String suitableForMute) {
        this.suitableForMute = suitableForMute;
    }
*/

    /**
    * Gets the list of MicroLPs in this KnowledgeObject.
    * 
    * @return A list with the MicroLP in this KnowledgeObject
    */      
    public ArrayList<MicroLP> getMicroLPs() {
        return microLPs;
    }

    /**
    * Sets the list of MicroLPs in this KnowledgeObject.
    * 
    * @param microLPs A list with the MicroLP to include in this KnowledgeObject
    */      
    public void setMicroLPs(ArrayList<MicroLP> microLPs) {
        this.microLPs = microLPs;
    }
    
    /**
    * Adds one property to this KnowledgeObject.
    *
    * @param k the name of the property to add
    * @param v the value of the property to add
    */
    public void addProperty(String k, String v) {
            properties.put(k,v);
    }
    
    /**
    * Gets all properties of this KnowledgeObject.
    *
    * <p>Properties are modelled as a Java Map. In order to get 
    * a certain property, the developers using this function may write: </p>
    *
    *
    * <pre>
    * Map m = myKnowledgeObject.getProperties();
    * String thePropertyValue = m.get(thePropertyName);
    * </pre>
    *
    * @return a Map with all the properties in this KnowledgeObject
    */       
    public Map<String,String> getProperties(){
        return properties;
    }

    /**
    * Gets the properties in this KnowledgeObject with the given key.
    *
    * <p>Searches the property whose key matches with <i>s</i> and returns it value.</p>
    *
    * @return The property value
    */ 
    public String getProperty(String s){
        return properties.get(s);
    }

    /**
    * Adds one MicroLP to this KnowledgeObject.
    * 
    * @param mlp The MicroLP to add
    */      
    public void addMicroLP(MicroLP mlp) {
        if ( !microLPs.contains(mlp) ) {
            microLPs.add(mlp);
        }
    }

    /**
    * Prints in the standard output a textual description of this KnowledgeObject.
    *
    * <p>The information printed includes the id and
    * a list of all the properties, presented as key-value pairs.</p>
    *
    */ 
    public void printKO() {
        System.out.println("\nKO identifier: " +id);
        
        Set<String> keys = properties.keySet();
        for (String k : keys) {
            System.out.println("\n\tProperty: "+ k);
            System.out.println("\n\tValue: "+ properties.get(k));
        }
    }

    /**
    * Provides a textual description of this KnowledgeObject.
    *
    * <p>The textual description of this KnowledgeObject contains its id and
    * a list of all the properties, presented as key-value pairs.</p>
    *
    * @return The String with the textual description
    */    
    public String toString() {
        String s= "";
        
        s=s+"\nKO identifier: " +id;
        
        Set<String> keys = properties.keySet();
        for (String k : keys) {
            s=s+"\n\tProperty: "+ k;
            s=s+"\n\tValue: "+ properties.get(k);
        }
        return s;
    }
    

    /**
    * Two KnowledgeObject are equal if they have the same id.
    * 
    * @param o the KnowledgeObject to compare
    * @return true if this KnowledgeObject has the same id as the KnowledgeObject received in <i>o</i>.
    */
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        KnowledgeObject that = (KnowledgeObject) o;
        return !(id != null ? !id.equals(that.id) : that.id != null);
    }

    @Override
    public int hashCode() {
        return id != null ? id.hashCode() : 0;
    }
}
