<!--
    * Document: ImsLDToCCM.xsl
    * Author:   Jaime Costa, j.costa@reading.ac.uk
    * Version: 0.1, 13/03/14
    * Created at Intelligent System Research Laboratory,
    * University of Reading, United Kingdom
    * web: http://www.isr.reading.ac.uk/
-->
<!DOCTYPE stylesheet [
        <!ENTITY owl "http://www.w3.org/2002/07/owl#" >
        <!ENTITY xsd "http://www.w3.org/2001/XMLSchema#" >
        <!ENTITY dc "http://dublincore.org/documents/dces/" >
        <!ENTITY rdfs "http://www.w3.org/2000/01/rdf-schema#" >
        <!ENTITY rdf "http://www.w3.org/1999/02/22-rdf-syntax-ns#" >
        <!ENTITY intui_PO "http://www.intuitel.eu/public/intui_PO.owl#" >
        <!ENTITY intui_CCM "http://www.intuitel.eu/public/model_c/intui_ccm.owl#" >
        <!ENTITY intui_CM "http://www.intuitel.eu/public/public/model_c/intui_cm.owl#" >
        ]>

<xsl:stylesheet xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
                xmlns:xml="http://www.w3.org/XML/1998/namespace"
                xml:base="http://www.intuitel.eu/public/model_c/intui_cm.owl"
                xmlns:owl="http://www.w3.org/2002/07/owl#"
                xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
                xmlns:intui_PO="http://www.intuitel.eu/public/intui_PO.owl#"
                xmlns:intui_CCM="http://www.intuitel.eu/public/model_c/intui_ccm.owl#"
                xmlns:dc="http://dublincore.org/documents/dces/">


    <xsl:output method="xml" version="1.0"/>

    <xsl:template match="/">
        <rdf:RDF xmlns="http://www.intuitel.eu/public/model_c/intui_ccm.owl"
                 xml:base="http://www.intuitel.eu/public/model_c/intui_ccm.owl"
                 xmlns:intui_PO="http://www.intuitel.eu/public/intui_PO.owl#"
                 xmlns:dc="http://dublincore.org/documents/dces/"
                 xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
                 xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
                 xmlns:intui_CCM="http://www.intuitel.eu/public/model_c/intui_ccm.owl#"
                 xmlns:owl="http://www.w3.org/2002/07/owl#">

            <!--Declaring the Ontology intui_CCM-->
            <owl:Ontology rdf:about="http://www.intuitel.eu/public/model_c/intui_ccm.owl">
                <owl:imports rdf:resource="http://www.intuitel.eu/public/intui_PO.owl"/>
                <owl:versionIRI rdf:resource="http://www.intuitel.eu/public/model_c/2013/09/27/intui_cm.owl"/>
                <dc:title>Intui CCM</dc:title>
            </owl:Ontology>

            <xsl:apply-templates/>
        </rdf:RDF>
    </xsl:template>

    <xsl:template match="organizations/learning-design">
        <xsl:apply-templates/>
    </xsl:template>

    <!--Learning Activities and Support Activities-->
    <xsl:template match="organizations/learning-design/components/activities/learning-activity
                        |organizations/learning-design/components/activities/support-activity">
        <xsl:for-each select="activity-description/item">
            <intui_PO:KnowledgeObject rdf:about="KO{@identifier}">
                <dc:title>
                    <xsl:value-of select="ancestor::learning-activity/title"/>
                </dc:title>
                <xsl:call-template name="getResourcehRef">
                    <xsl:with-param name="identifierref" select="@identifierref"/>
                    <xsl:with-param name="id" select="@identifier"/>
                </xsl:call-template>
                <!--if the time-limit exists-->
                <xsl:if test="complete-activity/time-limit">
                    <intui_PO:hasEstimatedLearningTime>
                        <xsl:value-of select="complete-activity/time-limit"/>
                    </intui_PO:hasEstimatedLearningTime>
                </xsl:if>
                <xsl:if test="not(complete-activity/time-limit)"/>
            </intui_PO:KnowledgeObject>
        </xsl:for-each>
    </xsl:template>

    <xsl:template name="getResourcehRef">
        <xsl:param name="identifierref"/>
        <xsl:param name="id"/>
        <!--get the Lms Element form the href of the resources-->
        <intui_PO:isLinkedWithLmsElement>
            <xsl:value-of select="//resource[@identifier = $identifierref]/@href"/>
        </intui_PO:isLinkedWithLmsElement>
        <!--get the Slom Package Element from the resources and setting a predefined path ..\KO{@href}-->
        <intui_PO:isLinkedWithSlomPackageElement>..\KO<xsl:value-of select="$id"/><xsl:text>\</xsl:text><xsl:value-of
                select="//resource[@identifier = $identifierref]/@href"/>
        </intui_PO:isLinkedWithSlomPackageElement>
    </xsl:template>

    <!--Learning-Objects inside environment-->
    <xsl:template match="organizations/learning-design/components/environments/environment/learning-object">
        <intui_PO:KnowledgeObject rdf:about="KO{item/@identifier}">
            <xsl:if test="item">
                <dc:title>
                    <xsl:value-of select="@identifier"/>
                </dc:title>
                <xsl:call-template name="getResourcehRef">
                    <xsl:with-param name="identifierref" select="item/@identifierref"/>
                    <xsl:with-param name="id" select="item/@identifier"/>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="not(item)"/>
        </intui_PO:KnowledgeObject>
    </xsl:template>

    <xsl:template match="organizations/learning-design/method">
        <xsl:apply-templates/>
    </xsl:template>
    <!--selecting the activity structures-->
    <xsl:template match="organizations/learning-design/components/activities">
        <xsl:for-each select="activity-structure">
            <!--defining an Ontology Object Property for each activity structure-->
            <owl:ObjectProperty
                    rdf:about="http://www.intuitel.eu/public/model_c/intui_ccm.owl#hasMicroLearningPathway{@identifier}">
                <rdfs:domain rdf:resource="&intui_PO;KnowledgeObject"/>
                <rdfs:range rdf:resource="&intui_PO;KnowledgeObject"/>
                <rdfs:subPropertyOf rdf:resource="&intui_PO;isAfterGoodPracticeMultiStage"/>
                <dc:title>
                    <xsl:text>Micro LearningPathway </xsl:text>
                </dc:title>
                <dc:description>
                    <xsl:text>mLP expressing an exemplary order of elements in accordance to multi-stage learning.</xsl:text>
                </dc:description>
            </owl:ObjectProperty>
        </xsl:for-each>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="organizations/learning-design/components/activities/activity-structure">
        <!--for each reference inside an activity structure get the correspondent Knowledge Objects-->
        <xsl:for-each select="learning-activity-ref">
            <xsl:if test="following-sibling::learning-activity-ref">
                <xsl:call-template name="getResourcesFromActivity">
                    <xsl:with-param name="actId" select="@ref"/>
                    <xsl:with-param name="actStructId" select="ancestor::activity-structure/@identifier"/>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="not(following-sibling::learning-activity-ref)"/>
        </xsl:for-each>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template name="getResourcesFromActivity">
        <xsl:param name="actId"/>
        <xsl:param name="actStructId"/>
        <xsl:for-each select="//learning-activity[@identifier = $actId]/activity-description/item">
            <intui_PO:KnowledgeObject rdf:about="KO{@identifier}">
                <!--test if current node has a sibling item-->
                <xsl:if test="following-sibling::item">
                    <xsl:variable name="ref" select="following-sibling::item/@identifier"/>
                    <xsl:text disable-output-escaping="yes"><![CDATA[<]]></xsl:text><xsl:text>intui_CCM:hasMicroLearningPathway</xsl:text><xsl:value-of
                        select="$actStructId"/><xsl:text disable-output-escaping="yes"> rdf:resource="KO</xsl:text><xsl:value-of select="$ref"/><xsl:text disable-output-escaping="yes">"/></xsl:text>
                </xsl:if>
                <xsl:if test="not(following-sibling::item)">
                    <xsl:variable name="ref" select="//activity-structure[@identifier = $actStructId]/learning-activity-ref[@ref = $actId]/following-sibling::learning-activity-ref/@ref"/>
                    <xsl:text disable-output-escaping="yes"><![CDATA[<]]></xsl:text><xsl:text>intui_CCM:hasMicroLearningPathway</xsl:text><xsl:value-of
                        select="$actStructId"/><xsl:text disable-output-escaping="yes"> rdf:resource="KO</xsl:text><xsl:value-of
                        select="//learning-activity[@identifier = $ref]/activity-description/item/@identifier"/><xsl:text disable-output-escaping="yes">"/></xsl:text>
                </xsl:if>
                <xsl:apply-templates/>
            </intui_PO:KnowledgeObject>
        </xsl:for-each>
    </xsl:template>

    <xsl:template name="getActivityResource">
        <xsl:param name="id"/>
        <xsl:for-each select="//activity-structure[@identifier = $id]/learning-activity-ref
                             |//activity-structure[@identifier = $id]/support-activity-ref">
            <xsl:variable name="ASRef" select="@ref"/>
            <xsl:for-each
                    select="//learning-activity[@identifier = $ASRef]/activity-description/item|//support-activity[@identifier = $ASRef]/activity-description/item">
                <intui_PO:containsKnowledgeObject rdf:resource="KO{@identifier}"/>
            </xsl:for-each>
        </xsl:for-each>
    </xsl:template>

    <!--Concept Container-->
    <xsl:template match="organizations/learning-design/method/play/act">
        <!--Test if the Act has an Identifier attribute-->
        <xsl:if test="@identifier">
            <intui_CCM:ConceptContainer rdf:about="CC{@identifier}{role-part/activity-structure-ref/@ref}">
                <!--Test if the act has a title element-->
                <xsl:if test="title">
                    <dc:title>
                        <xsl:value-of select="title"/>
                    </dc:title>
                </xsl:if>
                <xsl:call-template name="getActivityResource">
                    <xsl:with-param name="id" select="role-part/activity-structure-ref/@ref"/>
<!--                        <xsl:apply-templates/>
                    </xsl:with-param>-->
                </xsl:call-template>
            </intui_CCM:ConceptContainer>
        </xsl:if>
        <!--If the Act does not have an identifier attribute-->
        <xsl:if test="not(@identifier)">
            <intui_CCM:ConceptContainer>
                <!--Test if the act has a title element-->
                <xsl:if test="title">
                    <dc:title>
                        <xsl:value-of select="title"/>
                    </dc:title>
                </xsl:if>
                <xsl:if test="not(title)"/>
            </intui_CCM:ConceptContainer>
        </xsl:if>
        <xsl:apply-templates/>
    </xsl:template>


    <!--removes additional text-->
    <xsl:template match="text()"/>

</xsl:stylesheet>