<!--
    * Document: SlomToImsld.xsl
    * Author:   Jaime Costa, j.costa@reading.ac.uk
    * Version: 0.1, 11/03/14
    * Created at Intelligent System Research Laboratory,
    * University of Reading, United Kingdom
    * web: http://www.isr.reading.ac.uk/
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
                xmlns:imsld="http://www.imsglobal.org/xsd/imsld_v1p0"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:intui_PO="http://www.intuitel.eu/public/intui_PO.owl#">

    <xsl:output method="xml" version="1.0"/>

    <!--create a key to group by Knowledge Objects child nodes-->
    <xsl:key name="microLP" match="//KnowledgeObject" use="name(./*)"/>
    
    
    <xsl:template match="/">
        <manifest xmlns="http://www.imsglobal.org/xsd/imscp_v1p1" xsi:schemaLocation="http://www.imsglobal.org/xsd/imscp_v1p1 http://www.imsglobal.org/xsd/imscp_v1p1p3.xsd http://www.imsglobal.org/xsd/imsld_v1p0  http://www.imsglobal.org/xsd/IMS_LD_Level_A.xsd" identifier="generatedIMSLD">
            <metadata>
                <schema>IMS Metadata</schema>
                <schemaversion>1.2</schemaversion>
            </metadata>
            <organizations>
                <learning-design xmlns="http://www.imsglobal.org/xsd/imsld_v1p0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.imsglobal.org/xsd/imsld_v1p0 http://www.imsglobal.org/learningdesign/ldv1p0/IMS_LD_Level_A.xsd" identifier="generatedCourse" level="A" uri="http://intuitel.eu/public/generatedIMSLD">
                    <imsld:title>Generated IMS-LD</imsld:title>
                    <imsld:components>
                        <imsld:roles>
                            <imsld:learner identifier="Learner">
                                <imsld:title>Learner</imsld:title>
                            </imsld:learner>
                        </imsld:roles>
                        <imsld:activities>
                            <!--Run through every Knowledge Object-->
                            <xsl:for-each select="//KnowledgeObject">
                                <!--test if the Knowledge Object has an element called "isLinkedWithLmsElement"-->
                                <xsl:if test="isLinkedWithLmsElement">
                                    <!--if true create a learning activity from this KO-->
                                    <imsld:learning-activity identifier="Activity_{translate(@about,'','')}">
                                        <imsld:title><xsl:value-of select="title"/></imsld:title>
                                        <imsld:activity-description>
                                            <item identifier="{translate(@about,'','')}"/>
                                        </imsld:activity-description>
                                    </imsld:learning-activity>
                                </xsl:if>
                                <xsl:if test="not(isLinkedWithLmsElement)"/>
                            </xsl:for-each>
                            <!--for each element grouped before using the key microLP-->
                            <xsl:for-each select="//KnowledgeObject[generate-id()=generate-id(key('microLP',name(./*))[1])]">
                                <xsl:param name="currentActStrut" select="substring-after(name(./*),'hasMicroLearningPathway')"/>
                                <!--test if the current KO has an element with a name title or isLinkedWithLmsElement-->
                                <xsl:if test="not(name(./*) = 'title') and not(name(./*) = 'isLinkedWithLmsElement')">
                                    <!--if the previous condition is true, create an activity structure for each microLP-->
                                    <imsld:activity-structure identifier="{substring-after(name(./*),'hasMicroLearningPathway')}" structure-type="sequence">
                                        <xsl:for-each select="../KnowledgeObject/*">
                                            <xsl:if test="substring-after(name(.),'hasMicroLearningPathway') = $currentActStrut">
                                                <imsld:learning-activity-ref ref="Activity_{translate(../@about,'','')}"/>
                                            </xsl:if>
                                        </xsl:for-each>
                                    </imsld:activity-structure>
                                </xsl:if>
                            </xsl:for-each>
                        </imsld:activities>
                    </imsld:components>
                    <imsld:method>
                        <imsld:play>
                            <!--for each CC present, create an Act with an activity-structure-ref-->
                            <xsl:for-each select="//ConceptContainer">                                
                                <imsld:act identifier="{translate(@about,'','')}">
                                    <imsld:role-part>
                                        <imsld:role-ref ref="Learner"/>
                                        <imsld:activity-structure-ref ref="AS-{translate(@about,'','')}"/>
<!--                                        <imsld:activity-structure-ref ref="AS-{substring-after(@about,'AS-')}"/>-->
                                    </imsld:role-part>
                                </imsld:act>                                
                            </xsl:for-each>
                        </imsld:play>
                    </imsld:method>
                </learning-design>
            </organizations>
            <xsl:apply-templates/>
        </manifest>
    </xsl:template>

    <!--Template to create resources form KOs-->
    <xsl:template match="KnowledgeObject">
        <xsl:if test="isLinkedWithLmsElement">
            <resource identifier="{translate(@about,'','')}" href="{isLinkedWithLmsElement}">
                <file href="{isLinkedWithLmsElement}"/>
            </resource>
        </xsl:if>
        <xsl:apply-templates/>
    </xsl:template>

    <!--remove additional text-->
    <xsl:template match="text()"/>

</xsl:stylesheet>
