package org.intuitel.merger;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.Collections;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipException;
import java.util.zip.ZipFile;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.custommonkey.xmlunit.DetailedDiff;
import org.custommonkey.xmlunit.Diff;
import org.custommonkey.xmlunit.XMLUnit;
import org.junit.Assert;
import org.xml.sax.SAXException;

public class ExpectedXMLBasedTestBase 
{
    static final Log logger = LogFactory.getLog(ExpectedXMLBasedTestBase.class); 

	protected File inputFile;
	protected File expectedFile;
	protected File outputFile;
	public ExpectedXMLBasedTestBase(String inputFile2, String expectedFile2) throws IOException
	{
	    this.inputFile=getTestFile(inputFile2);
	    this.expectedFile=getTestFile(expectedFile2);
	    this.outputFile=getTempOutputFile();
	}
	protected File getTestFile(String inputFile) throws IOException
	{
	    URL url = ClassLoader.getSystemResource(inputFile);
	    if (url==null)
		throw new FileNotFoundException(inputFile);
	    return new File(url.getFile());
	}
	protected File getTempOutputFile() throws IOException
	{
	    
		File outputFile = File.createTempFile("intuitel_test", ".zip");
		
		return outputFile;
	}
	/**
	 * Match internal structure of ZIP files.
	 * Compare files with identical name.
	 * Check equivalence of XML files
	 * Use {@link #expectedFile} as pattern for matching 
	 * @throws IOException 
	 * @throws ZipException 
	 * @throws SAXException 
	 */
	protected void matchFiles() throws ZipException, IOException, SAXException
	{
	    
	    ZipFile expectedZip=  new ZipFile(expectedFile);
	    ZipFile outputZip = new ZipFile(outputFile);
	    
	    for (ZipEntry zipEntry : Collections.list(expectedZip.entries()))
		{
		    ZipEntry actualEntry = outputZip.getEntry(zipEntry.getName());
		    InputStream expectedStream = expectedZip.getInputStream(zipEntry);
		    InputStream actualStream = expectedZip.getInputStream(actualEntry);
		    matchStreams(expectedStream,actualStream);
		}
	    expectedZip.close();
	    outputZip.close();  
	}
	private void matchStreams(InputStream expectedStream, InputStream actualStream) throws SAXException, IOException
	{
	    XMLUnit.setIgnoreComments(true);
	    XMLUnit.setIgnoreAttributeOrder(true);
	    XMLUnit.setIgnoreWhitespace(true);
	    DetailedDiff d= new DetailedDiff(new Diff(new InputStreamReader(expectedStream), new InputStreamReader(actualStream)));
	    List differences = d.getAllDifferences();
	    Assert.assertTrue("Files are not equivalent. Differences:"+differences, d.similar());
	}

}
