/*
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Luis de-la-Fuente-Valentín, Universidad Internacional de La Rioja, UNIR, www.unir.net
 * Version: 1
 * Date: 2014-09-29
 * Copyright: Copyright (C) Universidad Internacional de La Rioja, UNIR
 * License: This software is provided as freeware. 

 Freeware products are provided free of charge. Freeware software may be used as many 
 times as you like, for as long as you like. You may copy and distribute copies of 
 this program provided that you keep this copyright notice and disclaimer of warranty
 intact, and recipients must be bound by the terms therein. You must not charge money
 or fees for the software product to anyone except to cover distribution costs. You 
 must acknowledge and cite the authorship of this software by UNIR. The copyright 
 holder reserves the right to reclassify this software as a non-freeware product at 
 any time (i.e. shareware, licensed royalty software, or public domain). Doing so will
 not modify the license agreement of previously distributed executables.
 */
 package org.intuitel.merger;

import org.intuitel.slom.SLOMUtil;
import java.io.File;
import java.util.Set;
import java.io.OutputStream;
import java.util.Iterator;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.*;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

import org.apache.commons.io.IOUtils;

import org.intuitel.slom.SLOM;
import org.intuitel.slom.SLOMUtil;

import java.io.*;
import java.util.*;
import java.util.zip.*;
import java.net.URL;
import org.intuitel.merger.BadFileException;

import org.w3c.dom.Document;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathFactory;  


/**
 * Implements SCORM serialization.
 *
 * <p>Further information of the transformation details can be found at the 
 * <a href="http:www.intuitel.de/resources">INTUITEL project page</a>, at deliverable D4.2</p>
 * 
 * @see Serializer
 * @see SerializerFactory
 * @see SMWScrapper
 */
public class SCORMXSLTSerializer extends XSLTSerializer{


    /**
    * Returns the path to the XSLT file that generates the CCM.
    * 
    */
    protected String getCCMXSLT() {
        return SLOMUtil.SCORM_TO_CCM_XSLT;
    }
    /**
    * Returns the path to the XSLT file that generates the CM.
    * 
    */    
    protected String getCMXSLT() {
        return SLOMUtil.SCORM_TO_CM_XSLT;
    }
    /**
    * Returns the path to the XSLT file that generates the SCORM manifest.
    * 
    */    
    protected String getToExternalFormatXSLT() {
        return SLOMUtil.CM_CCM_TO_SCORM_XSLT;
    }
    /**
    * Returns "SCORM".
    * 
    */
    protected String getExternalFormatName() {
        return SLOMUtil.SCORM_NAME;
    }

    /**
    * Reads a SCORM package and returns a SLOM object.
    *
    * <p>The unmarshall method reads content from a file and returns a SLOM object with
    * the information read.</p>
    *
    * <p>The method accepts a Set of File objects. In the case of SCORM packages, the 
    * set should only contain a single with the actual SCORM package.</p>
    */
    public SLOM unmarshall (Set<File> inputCourse) throws BadFileException, IOException {
//    A Set of File objects if more than one is needed.
        ZipFile zfile = null;
        ZipEntry manifestEntry = null;
        ZipEntry metadataEntry = null;
        InputStream manifestIn1 = null;
        InputStream manifestIn2 = null;
        InputStream manifestIn3 = null;
        String metadataLocation = null;
        InputStream metadataIn = null;
        ByteArrayOutputStream baosCM = new ByteArrayOutputStream();
        ByteArrayOutputStream baosCCM = new ByteArrayOutputStream();


        //get the File object, assuming that it is a zip file (imsld package)
        Iterator<File> it = inputCourse.iterator();
        if (!it.hasNext())
        {
            throw new BadFileException("Empty Set while parsing " + getExternalFormatName() + " package."); 
        }
        File f = it.next();

        //get the imsmanifest.xml inputStream
        try {
            zfile = new ZipFile(f);
        } catch (ZipException e) {
            System.err.println("Unable to open " + getExternalFormatName() + " package as ZIP file.");
        }

        manifestEntry = zfile.getEntry(SLOMUtil.IMSCP_MANIFEST_ZIPENTRY);
        manifestIn1 = zfile.getInputStream(manifestEntry);
        manifestIn2 = zfile.getInputStream(manifestEntry);
        manifestIn3 = zfile.getInputStream(manifestEntry);

        //use XSLT to translate to SLOM. Get two OutputStream (cm and ccm)
        InputStream xsltCmIn = SLOM.class.getResourceAsStream(getCMXSLT());
        InputStream xsltCcmIn = SLOM.class.getResourceAsStream(getCCMXSLT());

        /* ***************************
         start of SCORM specific code
         **************************/
       
        //read the manifest and get the metadata location as string
	try {
	  DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
	  DocumentBuilder db = dbf.newDocumentBuilder();
	  Document document = db.parse(manifestIn3);
	  XPathFactory xpf = XPathFactory.newInstance();
          XPath xp = xpf.newXPath();
	  metadataLocation = xp.evaluate("//organization//metadata/location/text()",
                document.getDocumentElement());	 
	  
	} catch (Exception e) {
	  System.err.println("Unable to parse retrieved RDF file");
	  e.printStackTrace();
	}
             
        metadataEntry = zfile.getEntry(metadataLocation);
        metadataIn = zfile.getInputStream(metadataEntry);
        String tDir = System.getProperty("java.io.tmpdir");
        String tmpMetadataPath = tDir + "/metadata.xml";
        FileOutputStream fosMetadata = new FileOutputStream(tmpMetadataPath);

        IOUtils.copy(metadataIn, fosMetadata);
        fosMetadata.close();

        transformFile(xsltCmIn,manifestIn1,baosCM, tmpMetadataPath);
        transformFile(xsltCcmIn,manifestIn2,baosCCM, tmpMetadataPath);
        /* ***************************
         end of SCORM specific code
         **************************/

        //create the SLOM object
        InputStream cm = new ByteArrayInputStream(baosCM.toByteArray());
        InputStream ccm = new ByteArrayInputStream(baosCCM.toByteArray());

        SLOM theSlom = new SLOM(cm, ccm);
        return theSlom;
    }

    private static void transformFile(InputStream stylesheet, InputStream input, OutputStream output, String tmpMetadataPath){
        try{

            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            DocumentBuilder builder = factory.newDocumentBuilder();
            Document doc = builder.parse(input);

            TransformerFactory tFactory = TransformerFactory.newInstance();
            StreamSource stylesource = new StreamSource(stylesheet);
            Transformer transformer = tFactory.newTransformer(stylesource);

            transformer.setOutputProperty(OutputKeys.INDENT,"yes");

        /* ***************************
         start of SCORM specific code
         **************************/

           transformer.setParameter("metadataFile", tmpMetadataPath); 

        /* ***************************
         end of SCORM specific code
         **************************/
            DOMSource dom = new DOMSource(doc);
            StreamResult result = new StreamResult(output);

            transformer.transform(dom,result);
        }
        catch (ParserConfigurationException e) {
            e.printStackTrace();
        } catch (SAXException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } catch (TransformerConfigurationException e) {
            e.printStackTrace();
        } catch (TransformerException e) {
            e.printStackTrace();
        }
    }
}
