/*
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Luis de-la-Fuente-Valentín, Universidad Internacional de La Rioja, UNIR, www.unir.net
 * Version: 1
 * Date: 2014-09-29
 * Copyright: Copyright (C) Universidad Internacional de La Rioja, UNIR
 * License: This software is provided as freeware. 

 Freeware products are provided free of charge. Freeware software may be used as many 
 times as you like, for as long as you like. You may copy and distribute copies of 
 this program provided that you keep this copyright notice and disclaimer of warranty
 intact, and recipients must be bound by the terms therein. You must not charge money
 or fees for the software product to anyone except to cover distribution costs. You 
 must acknowledge and cite the authorship of this software by UNIR. The copyright 
 holder reserves the right to reclassify this software as a non-freeware product at 
 any time (i.e. shareware, licensed royalty software, or public domain). Doing so will
 not modify the license agreement of previously distributed executables.
 */
package org.intuitel.slom;


/**
* Defines Error Codes for SLOM validation.
*
* <p>The org.intuitel.slom.SLOM.isValid() method checks whether 
* a course representation is written as SLOM or not. The result of 
* the validation is an error code that informs of the problem 
* (or the success). This class defines the allowed error codes</p> 
*
* <p>Further information of the SLOM format can be found at the 
* <a href="http:www.intuitel.de/resources">INTUITEL project page</a>, at deliverable D4.1</p>
* 
* @see org.intuitel.slom.SLOM
* @author  Luis de-la-Fuente-Valentín
* @since   1.0
*/
public enum SLOMError {
    VALID("VALID", "The provided zip file is a SLOM package"),
    NO_ZIP_FILE("NO_ZIP_FILE", "The provided file is not a ZIP file"),
    NO_CM_FOUND("NO_CM_FOUND", "The zip file does not contain a CM in the expected location."),
    NO_CCM_FOUND("NO_CCM_FOUND", "The zip file does not contain a CM in the expected location."),
    CM_NOT_VALID("CM_NOT_VALID","The provided CM is not valid"),
    CCM_NOT_VALID("CCM_NOT_VALID","The provided CCM is not valid");

    private final String code;
    private final String description;

    private SLOMError(String code, String description) {
    this.code = code;
    this.description = description;
    }

    /** 
    * Returns the error description
    *
    * @return The error description
    */
    public String getDescription() {
    return description;
    }

    /** 
    * Returns the error code
    *
    * @return The error code
    */    
    public String getCode() {
    return code;
    }

    @Override
    public String toString() {
    return code + ": " + description;
    }
}
