<!--
    * Document: ImsLDtoCM.xsl
    * Author:   Jaime Costa, j.costa@reading.ac.uk
    * Version: 0.1, 13/03/14
    * Created at Intelligent System Research Laboratory,
    * University of Reading, United Kingdom
    * web: http://www.isr.reading.ac.uk/
-->
<!DOCTYPE stylesheet [
        <!ENTITY owl "http://www.w3.org/2002/07/owl#" >
        <!ENTITY xsd "http://www.w3.org/2001/XMLSchema#" >
        <!ENTITY dc "http://dublincore.org/documents/dces/" >
        <!ENTITY rdfs "http://www.w3.org/2000/01/rdf-schema#" >
        <!ENTITY rdf "http://www.w3.org/1999/02/22-rdf-syntax-ns#" >
        <!ENTITY intui_PO "http://www.intuitel.eu/public/intui_PO.owl#" >
        <!ENTITY intui_CM "http://www.intuitel.eu/public/public/model_c/intui_cm.owl#" >
        ]>

<xsl:stylesheet xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
                xmlns:xml="http://www.w3.org/XML/1998/namespace"
                xml:base="http://www.intuitel.eu/public/model_c/intui_cm.owl"
                xmlns:owl="http://www.w3.org/2002/07/owl#"
                xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
                xmlns:intui_PO="http://www.intuitel.eu/public/intui_PO.owl#"
                xmlns:intui_CM="http://www.intuitel.eu/public/public/model_c/intui_cm.owl#"
                xmlns:dc="http://dublincore.org/documents/dces/">

    <xsl:output method="xml" version="1.0"/>

    <xsl:template match="/">
        <rdf:RDF xmlns="http://www.intuitel.eu/public/model_c/intui_cm.owl"
                 xml:base="http://www.intuitel.eu/public/model_c/intui_cm.owl"
                 xmlns:intui_PO="http://www.intuitel.eu/public/intui_PO.owl#"
                 xmlns:intui_CM="http://www.intuitel.eu/public/public/model_c/intui_cm.owl#"
                 xmlns:dc="http://dublincore.org/documents/dces/"
                 xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
                 xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
                 xmlns:owl="http://www.w3.org/2002/07/owl#">
            <!--declaration of the Ontology intui_CM-->
            <owl:Ontology rdf:about="http://www.intuitel.eu/public/model_c/intui_cm.owl">
<!--                <owl:imports rdf:resource="http://www.intuitel.eu/public/model_c/intui_ccm.owl"/>-->
                <owl:versionIRI rdf:resource="http://www.intuitel.eu/public/model_c/2013/09/27/intui_cm.owl"/>
                <dc:title>Intui CM</dc:title>
            </owl:Ontology>
            <!--declaration of the Ontology Property hasFlatHierarchicalNext-->
            <owl:ObjectProperty rdf:about="&intui_CM;hasFlatHierarchicalNext">
                <rdfs:domain rdf:resource="&intui_PO;ConceptContainer"/>
                <rdfs:range rdf:resource="&intui_PO;ConceptContainer"/>
                <rdfs:subPropertyOf rdf:resource="&intui_PO;hasTopDownLikeRelation"/>
                <dc:title>
                    <xsl:text>Flat hierarchy LP</xsl:text>
                </dc:title>
                <dc:description>
                    <xsl:text>LP expressing a rather flat hierarchy between CCs so that the overviews about the rather high-level topics are given before presenting the more detailed topics.</xsl:text>
                </dc:description>
            </owl:ObjectProperty>
            <xsl:apply-templates/>
        </rdf:RDF>
    </xsl:template>

    <xsl:template match="organizations/learning-design">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="organizations/learning-design/method">
        <xsl:apply-templates/>
    </xsl:template>


    <!--Get the Knowledge objects contained in a Concept Container-->
    <!--getting the references from support-activities as well as learning-activities-->
    <xsl:template name="getActivityResource">
        <xsl:param name="id" select="UNDEFINED"/>
        <xsl:for-each select="//activity-structure[@identifier = $id]/learning-activity-ref
                             |//activity-structure[@identifier = $id]/support-activity-ref">
            <xsl:for-each select="//learning-activity|//support-activity">
            </xsl:for-each>
            <intui_PO:containsKnowledgeObject rdf:resource="KO{@ref}"/>
        </xsl:for-each>
    </xsl:template>

    <!--Concept Container-->
    <xsl:template match="organizations/learning-design/method/play/act">
        <!--Test if the Act has an Identifier attribute-->
        <xsl:if test="@identifier">
            <intui_CM:ConceptContainer rdf:about="CC{@identifier}{role-part/activity-structure-ref/@ref}">
                <!--Test if the act has a title element-->
                <xsl:if test="title">
                    <dc:title>
                        <xsl:value-of select="title"/>
                    </dc:title>
                </xsl:if>
                <xsl:if test="not(title)"/>
                <!--Test if there is another act in the same play node-->
                <xsl:if test="following-sibling::act/role-part">
                    <intui_CM:hasFlatHierarchicalNext rdf:resource="CC{following-sibling::act/@identifier}{following-sibling::act/role-part/activity-structure-ref/@ref}"/>
                </xsl:if>
                <!--if not test if there is another act in the following play node-->
                <xsl:if test="not(following-sibling::act/role-part)">
                    <xsl:if test="ancestor::play/following-sibling::play/act/role-part">
                        <intui_CM:hasFlatHierarchicalNext rdf:resource="CC{ancestor::play/following-sibling::play/act/@identifier}{ancestor::play/following-sibling::play/act/role-part/activity-structure-ref/@ref}"/>
                    </xsl:if>
                    <xsl:if test="not(ancestor::play/following-sibling::play/act/role-part)"/>
                </xsl:if>
            </intui_CM:ConceptContainer>
        </xsl:if>
        <!--If the Act does not have an identifier attribute-->
        <xsl:if test="not(@identifier)">
            <intui_PO:ConceptContainer>
                <!--Test if the act has a title element-->
                <xsl:if test="title">
                    <dc:title>
                        <xsl:value-of select="title"/>
                    </dc:title>
                </xsl:if>
                <xsl:if test="not(title)"/>
                <!--Test if there is another act in the same play node-->
                <xsl:if test="following-sibling::act/role-part">
                    <intui_CM:hasFlatHierarchicalNext rdf:resource="CC{following-sibling::act/@identifier}{following-sibling::act/role-part/activity-structure-ref/@ref}"/>
                </xsl:if>
                <!--if not test if there is another act in the following play node-->
                <xsl:if test="not(following-sibling::act/role-part)">
                    <xsl:if test="ancestor::play/following-sibling::play/act/role-part">
                        <intui_CM:hasFlatHierarchicalNext rdf:resource="CC{ancestor::play/following-sibling::play/act/@identifier}{ancestor::play/following-sibling::play/act/role-part/activity-structure-ref/@ref}"/>
                    </xsl:if>
                    <xsl:if test="not(ancestor::play/following-sibling::play/act/role-part)"/>
                </xsl:if>
            </intui_PO:ConceptContainer>
        </xsl:if>
        <xsl:apply-templates/>
    </xsl:template>

    <!--removes additional text-->
    <xsl:template match="text()"/>

</xsl:stylesheet>
