<!--
    * Document   : SlomToScorm.xsl
    * Author:   Oscar Garcia, oscar.garciaperales@tiekinetix.com
    * Author:   Oscar Soriano, oscar.soriano@tiekinetix.com
    * Version: 0.2, 22/08/14
    * Created at : TIE Kinetix, The Netherlands
    * web        : http://www.tiekinetix.com/
    * Description: Purpose of transformation follows.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
                xmlns:dc="http://purl.org/dc/elements/1.1/" 
                xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns" 
                xmlns:owl="http://www.w3.org/2002/07/owl#"
                xmlns:adlcp="http://www.adlnet.org/xsd/adlcp_v1p3"
                xmlns:intui="http://intuitel.eu/public/intui_PO.owl"
                xmlns:intui_CM="http://www.intuitel.eu/public/public/model_c/intui_cm.owl#" 
                xmlns:intui_CCM="http://www.intuitel.eu/public/public/model_c/intui_ccm.owl#" 
                xmlns:intui_PO="http://www.intuitel.eu/public/intui_PO.owl#">
    <xsl:output method="xml"/>


    <xsl:template match="/">
        <manifest identifier="com.scorm.golfsamples.contentpackaging.metadata.20043rd" version="1"
                  xmlns="http://www.imsglobal.org/xsd/imscp_v1p1"
                  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                  xmlns:adlcp="http://www.adlnet.org/xsd/adlcp_v1p3"
                  xmlns:adlseq="http://www.adlnet.org/xsd/adlseq_v1p3"
                  xmlns:adlnav="http://www.adlnet.org/xsd/adlnav_v1p3"
                  xmlns:imsss="http://www.imsglobal.org/xsd/imsss"
                  xmlns:lom="http://ltsc.ieee.org/xsd/LOM"
                  xsi:schemaLocation="http://www.imsglobal.org/xsd/imscp_v1p1 imscp_v1p1.xsd
                              http://www.adlnet.org/xsd/adlcp_v1p3 adlcp_v1p3.xsd
                              http://www.adlnet.org/xsd/adlseq_v1p3 adlseq_v1p3.xsd
                              http://www.adlnet.org/xsd/adlnav_v1p3 adlnav_v1p3.xsd
                              http://www.imsglobal.org/xsd/imsss imsss_v1p0.xsd
                              http://ltsc.ieee.org/xsd/LOM lom.xsd">
	
            <metadata>
                <schema>ADL SCORM</schema>
                <schemaversion>2004 3rd Edition</schemaversion>
            </metadata>

            <organizations>
                <xsl:apply-templates select='//NamedIndividual[type/@resource="http://www.intuitel.eu/public/intui_PO.owl#ConceptContainer"]'/> 
            </organizations>
            
            <resources> 
                <xsl:apply-templates select='//NamedIndividual[type/@resource="http://www.intuitel.eu/public/intui_PO.owl#KnowledgeObject"]'/> 
            </resources>            
        </manifest>
    </xsl:template>
    
    <xsl:template match='//NamedIndividual[type/@resource="http://www.intuitel.eu/public/intui_PO.owl#ConceptContainer"]'>
        <organization identifier="{substring-after(@about,'#')}">
            <xsl:if test="title!=''">
                <title>
                    <xsl:value-of select="title"/>
                </title>
            </xsl:if>
            
            <xsl:variable name="ccType" select="@about"/>
            <xsl:for-each select='//NamedIndividual[type/@resource="http://www.intuitel.eu/public/intui_PO.owl#KnowledgeObject" and isContainedByConceptContainer/@resource=$ccType]'>
                <xsl:call-template name="writeItem">
                    <xsl:with-param name="resourceID" select="." />
                </xsl:call-template>
            </xsl:for-each>    
                   
            <xsl:if test="description!=''">
                <metadata>
                    <lom>
                        <general>
                            <description>
                                <string language="{language}">
                                    <xsl:value-of select="description"/>
                                </string>
                            </description>
                        </general>
                    </lom>
                </metadata>
            </xsl:if>
        </organization>
    </xsl:template>
    
    <xsl:template name='writeItem'>
        <xsl:param name="resourceID" />

        <!--<item identifier="{substring-after(@about,'#')}" identifierref='resource_{count(preceding::NamedIndividual[type/@resource="http://www.intuitel.eu/public/intui_PO.owl#KnowledgeObject"])+1}'>-->
        <item identifier="{substring-after(@about,'#')}" identifierref="resource_{substring-after(@about,'#')}">
            <xsl:if test="title!=''">
                <title>
                    <xsl:value-of select="title"/>
                </title>
            </xsl:if>

            <xsl:if test="description!=''">
                <metadata>
                    <lom>
                        <general>
                            <description>
                                <string language="{hasLanguage}">
                                    <xsl:value-of select="description"/>
                                </string>
                            </description>
                        </general>
                    </lom>
                </metadata>
            </xsl:if>
        </item> 
    </xsl:template>
    
    <xsl:template match='//NamedIndividual[type/@resource="http://www.intuitel.eu/public/intui_PO.owl#KnowledgeObject"]'>        
        <!--<resource identifier='resource_{count(preceding::NamedIndividual[type/@resource="http://www.intuitel.eu/public/intui_PO.owl#KnowledgeObject"])+1}' type="webcontent" adlcp:scormType="sco" href="{isLinkedWithLmsElement}">                -->
        <resource identifier="resource_{substring-after(@about,'#')}" type="webcontent" adlcp:scormType="sco" href="{isLinkedWithLmsElement}">
            <metadata>
                <lom>
                    <general>
                        <description>
                            <string language="{hasLanguage}">
                                <xsl:value-of select="description"/>
                            </string>
                        </description>
                    </general>
                </lom>
            </metadata>    
        </resource>
    </xsl:template>
</xsl:stylesheet>
